Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(664)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutView.cpp

Issue 2770123003: Replace ASSERT with DCHECK in core/layout/ excluding subdirs (Closed)
Patch Set: Split some DCHECKs and add DCHECK_ops wherever possible Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutView.cpp
diff --git a/third_party/WebKit/Source/core/layout/LayoutView.cpp b/third_party/WebKit/Source/core/layout/LayoutView.cpp
index 374293e898c154a038231f87d6e7e1010b63b406..28f4b44192c58a177cdbc9f9ca6c7632fe58e42b 100644
--- a/third_party/WebKit/Source/core/layout/LayoutView.cpp
+++ b/third_party/WebKit/Source/core/layout/LayoutView.cpp
@@ -129,7 +129,7 @@ bool LayoutView::hitTestNoLifecycleUpdate(HitTestResult& result) {
TRACE_EVENT_BEGIN0("blink,devtools.timeline", "HitTest");
m_hitTestCount++;
- ASSERT(!result.hitTestLocation().isRectBasedTest() ||
+ DCHECK(!result.hitTestLocation().isRectBasedTest() ||
result.hitTestRequest().listBased());
commitPendingSelection();
@@ -199,7 +199,7 @@ bool LayoutView::canHaveChildren() const {
}
void LayoutView::layoutContent() {
- ASSERT(needsLayout());
+ DCHECK(needsLayout());
LayoutBlockFlow::layout();
@@ -210,7 +210,7 @@ void LayoutView::layoutContent() {
#if DCHECK_IS_ON()
void LayoutView::checkLayoutState() {
- ASSERT(!m_layoutState->next());
+ DCHECK(!m_layoutState->next());
}
#endif
@@ -286,7 +286,7 @@ void LayoutView::layout() {
.invalidateSVGRootsWithRelativeLengthDescendents(&layoutScope);
}
- ASSERT(!m_layoutState);
+ DCHECK(!m_layoutState);
if (!needsLayout())
return;
@@ -565,8 +565,8 @@ LayoutSize LayoutView::offsetForFixedPosition(bool includePendingScroll) const {
// FIXME: Paint invalidation should happen after scroll updates, so there
// should be no pending scroll delta.
// However, we still have paint invalidation during layout, so we can't
// ASSERT for now. crbug.com/434950.
// ASSERT(m_frameView->pendingScrollDelta().isZero());
// If we have a pending scroll, invalidate the previous scroll position.
if (includePendingScroll && !m_frameView->pendingScrollDelta().isZero())
adjustment -= m_frameView->pendingScrollDelta();
@@ -565,8 +565,8 @@ LayoutSize LayoutView::offsetForFixedPosition(bool includePendingScroll) const {
// should be no pending scroll delta.
// However, we still have paint invalidation during layout, so we can't
- // ASSERT for now. crbug.com/434950.
- // ASSERT(m_frameView->pendingScrollDelta().isZero());
+ // DCHECK for now. crbug.com/434950.
+ // DCHECK(m_frameView->pendingScrollDelta().isZero());
// If we have a pending scroll, invalidate the previous scroll position.
if (includePendingScroll && !m_frameView->pendingScrollDelta().isZero())
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutView.h ('k') | third_party/WebKit/Source/core/layout/ListMarkerText.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698